External Resources
==================

Blogs
-----

 * `a FAUCET dev blog <https://www.vandervecken.com/faucet/>`_

Configuration
-------------

 * `faucetagent <https://github.com/faucetsdn/faucetagent>`_ : gNMI agent for faucet configuration
 * `faucetconfrpc <https://github.com/IQTLabs/faucetconfrpc>`_ : RPC for Faucet configuration Files

Integrations
------------

 * `doveSnap <https://github.com/iqtlabs/dovesnap>`_ : Docker OVS Network Plugin
 * `pipette <https://github.com/IQTLabs/pipette>`_ : SDN/NFV coprocessor controller
 * `Poseidon <https://github.com/IQTLabs/poseidon>`_ : SDN enabled traffic collection, feeding machine learning algorithms
 * `DAQ <https://github.com/faucetsdn/daq>`_ : Device Automated Qualification framework for IoT devices based on Faucet
 * `Forch <https://github.com/faucetsdn/forch>`_ : Faucet Orchestrator for controlling and monitoring a faucet-based network
 * `GNS3 Faucet <https://github.com/mwutzke/gns3-faucet>`_ A Faucet GNS3 appliance, to manage GNS3 OVS nodes

Online Tutorials
----------------

 * http://docs.openvswitch.org/en/latest/tutorials/faucet/
 * http://costiser.ro/2017/03/07/sdn-lesson-2-introducing-faucet-as-an-openflow-controller/
 * https://inside-openflow.com/openflow-tracks/faucet-controller-application-technical-track/
 * https://blog.cyberreboot.org/building-a-software-defined-network-with-raspberry-pis-and-a-zodiac-fx-switch-97184032cdc1

Tutorial Videos
---------------

 * https://www.youtube.com/watch?v=fuqzzjmcwlI
